@@ -1,9 +1,14 @@
 #define PY_SSIZE_T_CLEAN
+
 #include <Python.h>
+#include <structmember.h>
 
 extern PyTypeObject StackType;
+extern PyTypeObject QueueType;
 extern PyTypeObject LinkedType;
+extern PyTypeObject HashMapType;
 extern PyTypeObject RingBufferType;
+extern PyTypeObject PriorityQueueType;
 
 static PyObject *
 magic(PyObject *self, PyObject *args)
@@ -22,17 +27,23 @@ static PyMethodDef StructuraMethods[] = {
 };
 
 static struct PyModuleDef structuramodule = {
-    PyModuleDef_HEAD_INIT,
-    "structura",
-    "Python interface for the Structura library.",
-    -1,
-    StructuraMethods,
+    .m_base = PyModuleDef_HEAD_INIT,
+    .m_name = "structura",
+    .m_doc = "Python interface for the structura.",
+    .m_size = -1,
+    .m_methods = StructuraMethods,
 };
 
 PyMODINIT_FUNC PyInit_structura(void)
 {
     PyObject *module = PyModule_Create(&structuramodule);
 
+    /* add version */
+    PyModule_AddStringConstant(module, "__version__", "0.3.0");
+
+    /* add docstring */
+    PyModule_AddStringConstant(module, "__doc__", "Python interface for the structura.");
+
     /* Add int constant by name */
     PyModule_AddIntConstant(module, "__ANSWER", 42);
 
@@ -57,5 +68,26 @@ PyMODINIT_FUNC PyInit_structura(void)
     Py_INCREF(&LinkedType);
     PyModule_AddObject(module, "LinkedList", (PyObject *)&LinkedType);
 
+    /* Add Queue type */
+    if (PyType_Ready(&QueueType) < 0)
+        return NULL;
+
+    Py_INCREF(&QueueType);
+    PyModule_AddObject(module, "Queue", (PyObject *)&QueueType);
+
+    /* Add HashMap type */
+    if (PyType_Ready(&HashMapType) < 0)
+        return NULL;
+
+    Py_INCREF(&HashMapType);
+    PyModule_AddObject(module, "HashMap", (PyObject *)&HashMapType);
+
+    /* Add PriorityQueue type */
+    if (PyType_Ready(&PriorityQueueType) < 0)
+        return NULL;
+
+    Py_INCREF(&PriorityQueueType);
+    PyModule_AddObject(module, "PriorityQueue", (PyObject *)&PriorityQueueType);
+
     return module;
 }
\ No newline at end of file
